/**
 * @file
 * Contains plugin.js.
 */

'use strict';

(function () {
  CKEDITOR.plugins.add('blockimagebase64paste', {
    init: function (editor) {

      // Function to check and remove base64 images.
      function replaceBase64Images(html) {
        // Regular expression to detect base64-encoded images in the HTML.
        const regex = /<img[^>]*src="data:image\/(bmp|dds|gif|jpg|jpeg|png|psd|pspimage|tga|thm|tif|tiff|yuv|ai|eps|ps|svg);base64,[^"]*?"[^>]*>/gi;

        // Replace the base64 image with an empty string and show an alert.
        return html.replace(regex, function (img) {
          alert(Drupal.t('Pasting base64-encoded images is not allowed.'));
          return '';
        });
      }

      // Function to check for base64 images when pasting in the editor (WYSIWYG or source mode).
      function checkBase64Images() {
        if (editor.readOnly) {
          return;
        }

        // Delay to allow the content to be pasted before checking.
        setTimeout(function () {
          // If in WYSIWYG mode, check the editor's content.
          if (editor.mode === 'wysiwyg') {
            var content = editor.getData();
            editor.setData(replaceBase64Images(content));
          }
          // If in source mode, check the raw HTML content.
          else if (editor.mode === 'source') {
            var textarea = editor.editable().$;
            textarea.value = replaceBase64Images(textarea.value);
          }
        }, 100);
      }

      // Listen for paste events in both WYSIWYG and source modes.
      editor.on('paste', function (event) {
        var content = event.data.dataValue;
        if (!content) {
          return;
        }

        // Replace base64 images in the pasted content.
        event.data.dataValue = replaceBase64Images(content);
      });

      // Listen for switching between WYSIWYG and source modes to catch base64 images.
      editor.on('mode', function () {
        // Check for base64 images in both WYSIWYG and source modes after switching modes.
        checkBase64Images();
      });

      // Ensure base64 images are blocked when switching modes or pasting.
      editor.on('beforeCommandExec', function (event) {
        if (event.data.name === 'source') {
          checkBase64Images();
        }
      });
    },
  });
})();
